==> dl-0.0.1.tgz: package/lib/ocdn/Ocdn.js <==
var Class = require("core").Class;
var Event = require('core').Event.Event;
var ErrorEvent = require('core').Event.ErrorEvent;
var EventDispatcher = require('core').Event.EventDispatcher; 
var DriverAbstract = require("./driver/DriverAbstract.js").DriverAbstract;
var Crypto = require("core").Common.Crypto;

/**
 * @class Ocdn
 */
var Ocdn = function(){
    this.Extends = EventDispatcher;
    
    this._driver = null;
    this._application = null;
    
    this.initialize = function(application, driver, credential){
        var that = this;
        ClassDriver = require("./driver/" + driver + ".js")[driver];
        this._driver = new ClassDriver(application, credential);
        this._driver.addEventListener(DriverAbstract.Event.LOADED, function(e){
            that.dispatchEvent(new Event(Ocdn.Event.LOADED, e.data));
        });
        this._driver.addEventListener(DriverAbstract.Event.ERROR, function(e){
            that.dispatchEvent(new ErrorEvent(Ocdn.Event.ERROR, e, -4, 'Ocdn set error'));
        });
        this._application = application;
    };
    
    this.set = function(data){
        this._driver.set(data);
    };
    
    this.get = function(fileId, title, ext){
        ext = ext || "";
        title = title || "";
        return 'http://s3-eu-west-1.amazonaws.com/kstudzinskipub/' + '<APP_ID>/<TRAN>/<FILE_ID>.<EXT><TITLE>'.replace('<APP_ID>', this._driver.getShortAppId(this._application)).replace('<TITLE>', title).replace('<TRAN>', this._encode_transformations(fileId)).replace('<FILE_ID>', fileId).replace('<EXT>', ext);
    };
    
    this._encode_transformations = function(fileId){
        var trans = "00";
        var OCDN_KEY = 'J&D87ftasd67SFD%&^asdf';
        var md5 = Crypto.md5(fileId + trans + OCDN_KEY);
        var base64 = new Buffer(md5[0] + md5[1] + ';' + trans, 'binary').toString('base64');
        return base64.replace('=', '_');
    };
};

Ocdn = new Class( new Ocdn() );
Ocdn.Event = {};
Ocdn.Event.LOADED = 'Ocdn.Event.LOADED';
Ocdn.Event.ERROR = 'Ocdn.Event.ERROR';
exports.Ocdn = Ocdn;

==> dl-0.0.3.tgz: package/lib/ocdn/Ocdn.js <==
var Class = require("core").Class;
var Event = require('core').Event.Event;
var ErrorEvent = require('core').Event.ErrorEvent;
var EventDispatcher = require('core').Event.EventDispatcher; 
var DriverAbstract = require("./driver/DriverAbstract.js").DriverAbstract;
var Crypto = require("core").Common.Crypto;
var Assertions = require("core").Common.Assertions;

/**
 * @class Ocdn
 */
var Ocdn = function(){
    this.Extends = EventDispatcher;
    
    this._driver = null;
    this._application = null;
    this._credential = null;
    
    this.initialize = function(application, driver, credential){
        var that = this;
        ClassDriver = require("./driver/" + driver + ".js")[driver];
        this._driver = new ClassDriver(application, credential);
        this._driver.addEventListener(DriverAbstract.Event.LOADED, function(e){
            that.dispatchEvent(new Event(Ocdn.Event.LOADED, e.data));
        });
        this._driver.addEventListener(DriverAbstract.Event.ERROR, function(e){
            that.dispatchEvent(new ErrorEvent(Ocdn.Event.ERROR, e, -4, 'Ocdn set error'));
        });
        this._application = application;
        this._credential = credential;
    };
    
    this.set = function(data, name){
        this._driver.set(data, name);
    };

    this.getDriver = function () {
        return this._driver;
    };
    
    this.get = function(plugin, fileId, ext, title){
        Assertions.isString(plugin);
        Assertions.isString(fileId);

        ext = ext || "";
        title = title || "";

        return 'http://' + this._credential.hosts[0].host + '/' + this._credential.buckets.BUCKET_TEMP + '/' + Ocdn.PATH_TEMPLATE.replace('<PLUGIN>', plugin).replace('<APP_ID>', this._driver.getShortAppId(this._application)).replace('<TITLE>', title).replace('<TRAN>', this._encode_transformations(fileId)).replace('<FILE_ID>', fileId).replace('<EXT>', ext);
    };
    
    this._encode_transformations = function(fileId){
        var trans = "00";
        var OCDN_KEY = 'J&D87ftasd67SFD%&^asdf';
        var md5 = Crypto.md5(fileId + trans + OCDN_KEY);
        var base64 = new Buffer(md5[0] + md5[1] + ';' + trans, 'binary').toString('base64');
        return base64.replace('=', '_');
    };
};

Ocdn = new Class( new Ocdn() );
Ocdn.Event = {};
Ocdn.Event.LOADED = 'Ocdn.Event.LOADED';
Ocdn.Event.ERROR = 'Ocdn.Event.ERROR';

Ocdn.PATH_TEMPLATE = '<PLUGIN>/<APP_ID>/<TRAN>/<FILE_ID>.<EXT><TITLE>';

exports.Ocdn = Ocdn;
